% function [M_h, M_v] = AlignInputModeCleaner(d_mc1mc2, d_mc1mc3, Radius)
% 
% This function returns the shift of the cavity mode waist and angle as a
% function of the three input mirror angles.  Outptu is two 2x3 matrices,
% with each column representing MC1, MC2 and MC3 in turn. The first row is
% the mode displacement,  the second row is the mode angle. The first
% matrix is for Horizontal,  the second for vertical tunings.
%
% d_mc1mc2 is the distance MC1 to MC2,  and d_mc1mc3 is the distance 
% MC1 to MC3.
%
% Good numbers are d_mc1mc2 = 12,  d_mc1mc3 = 0.4,  and Radius = 17.25.
%
% The math here is based on T09xxxxxx
%
%
function [M_h, M_v] = AlignInputModeCleaner(d_mc1mc2, d_mc1mc3, Radius)

try, d_mc1mc2; 
catch 
    d_mc1mc2 = 12;
    d_mc1mc3 = 0.4;
    Radius = 17.25;
end

%% Horizontal
 L = d_mc1mc2;
 l = d_mc1mc3/2;
 curved_AOI = asin(l / L);
 R_eff = Radius*cos(curved_AOI);
 
 flat_angle = (R_eff-L) / (R_eff-l-L);
 curved_angle = -R_eff/(R_eff-l-L);
 
 M_h = - [ L 0 -L;  flat_angle, curved_angle, flat_angle];
 
%% Vertical
 L = d_mc1mc2;
 l = d_mc1mc3/2;
 
 curved_AOI = asin(l / L);
 R_eff = Radius/cos(curved_AOI);
 
 flat_angle = sqrt( (L+l)/(2*L));
 curved_angle = sqrt((L^2-l^2)/L^2);
 
 
 M_v = - [ (R_eff-L)*flat_angle R_eff*curved_angle (R_eff-L)*flat_angle; 
           -L/(l+L)*flat_angle      0              L/(l+L)*flat_angle]; 



